tonalitytools.are_stepwise_descending_notes
===========================================

.. autofunction:: abjad.tools.tonalitytools.are_stepwise_descending_notes.are_stepwise_descending_notes
   :noindex:
